==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/HTTPChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPChaosFluentImpl<A extends HTTPChaosFluent<A>> extends BaseFluent<A> implements HTTPChaosFluent<A>{
  public HTTPChaosFluentImpl() {
  }
  public HTTPChaosFluentImpl(HTTPChaos instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private HTTPChaosSpecBuilder spec;
  private HTTPChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public HTTPChaosFluent.MetadataNested<A> withNewMetadata() {
    return new HTTPChaosFluentImpl.MetadataNestedImpl();
  }
  public HTTPChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new HTTPChaosFluentImpl.MetadataNestedImpl(item);
  }
  public HTTPChaosFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public HTTPChaosFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public HTTPChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public HTTPChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(HTTPChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new HTTPChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public HTTPChaosFluent.SpecNested<A> withNewSpec() {
    return new HTTPChaosFluentImpl.SpecNestedImpl();
  }
  public HTTPChaosFluent.SpecNested<A> withNewSpecLike(HTTPChaosSpec item) {
    return new HTTPChaosFluentImpl.SpecNestedImpl(item);
  }
  public HTTPChaosFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public HTTPChaosFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new HTTPChaosSpecBuilder().build());
  }
  public HTTPChaosFluent.SpecNested<A> editOrNewSpecLike(HTTPChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public HTTPChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(HTTPChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new HTTPChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public HTTPChaosFluent.StatusNested<A> withNewStatus() {
    return new HTTPChaosFluentImpl.StatusNestedImpl();
  }
  public HTTPChaosFluent.StatusNested<A> withNewStatusLike(HTTPChaosStatus item) {
    return new HTTPChaosFluentImpl.StatusNestedImpl(item);
  }
  public HTTPChaosFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public HTTPChaosFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new HTTPChaosStatusBuilder().build());
  }
  public HTTPChaosFluent.StatusNested<A> editOrNewStatusLike(HTTPChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPChaosFluentImpl that = (HTTPChaosFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<HTTPChaosFluent.MetadataNested<N>> implements HTTPChaosFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) HTTPChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends HTTPChaosSpecFluentImpl<HTTPChaosFluent.SpecNested<N>> implements HTTPChaosFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(HTTPChaosSpec item) {
      this.builder = new HTTPChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new HTTPChaosSpecBuilder(this);
    }
    HTTPChaosSpecBuilder builder;
    public N and() {
      return (N) HTTPChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends HTTPChaosStatusFluentImpl<HTTPChaosFluent.StatusNested<N>> implements HTTPChaosFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(HTTPChaosStatus item) {
      this.builder = new HTTPChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new HTTPChaosStatusBuilder(this);
    }
    HTTPChaosStatusBuilder builder;
    public N and() {
      return (N) HTTPChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/HTTPChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPChaosFluentImpl<A extends HTTPChaosFluent<A>> extends BaseFluent<A> implements HTTPChaosFluent<A>{
  public HTTPChaosFluentImpl() {
  }
  public HTTPChaosFluentImpl(HTTPChaos instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private HTTPChaosSpecBuilder spec;
  private HTTPChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public HTTPChaosFluentImpl.MetadataNested<A> withNewMetadata() {
    return new HTTPChaosFluentImpl.MetadataNestedImpl();
  }
  public HTTPChaosFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new HTTPChaosFluentImpl.MetadataNestedImpl(item);
  }
  public HTTPChaosFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public HTTPChaosFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public HTTPChaosFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public HTTPChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(HTTPChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new HTTPChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public HTTPChaosFluentImpl.SpecNested<A> withNewSpec() {
    return new HTTPChaosFluentImpl.SpecNestedImpl();
  }
  public HTTPChaosFluentImpl.SpecNested<A> withNewSpecLike(HTTPChaosSpec item) {
    return new HTTPChaosFluentImpl.SpecNestedImpl(item);
  }
  public HTTPChaosFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public HTTPChaosFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new HTTPChaosSpecBuilder().build());
  }
  public HTTPChaosFluentImpl.SpecNested<A> editOrNewSpecLike(HTTPChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public HTTPChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(HTTPChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new HTTPChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public HTTPChaosFluentImpl.StatusNested<A> withNewStatus() {
    return new HTTPChaosFluentImpl.StatusNestedImpl();
  }
  public HTTPChaosFluentImpl.StatusNested<A> withNewStatusLike(HTTPChaosStatus item) {
    return new HTTPChaosFluentImpl.StatusNestedImpl(item);
  }
  public HTTPChaosFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public HTTPChaosFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new HTTPChaosStatusBuilder().build());
  }
  public HTTPChaosFluentImpl.StatusNested<A> editOrNewStatusLike(HTTPChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPChaosFluentImpl that = (HTTPChaosFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<HTTPChaosFluentImpl.MetadataNested<N>> implements HTTPChaosFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) HTTPChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends HTTPChaosSpecFluentImpl<HTTPChaosFluentImpl.SpecNested<N>> implements HTTPChaosFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(HTTPChaosSpec item) {
      this.builder = new HTTPChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new HTTPChaosSpecBuilder(this);
    }
    HTTPChaosSpecBuilder builder;
    public N and() {
      return (N) HTTPChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends HTTPChaosStatusFluentImpl<HTTPChaosFluentImpl.StatusNested<N>> implements HTTPChaosFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(HTTPChaosStatus item) {
      this.builder = new HTTPChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new HTTPChaosStatusBuilder(this);
    }
    HTTPChaosStatusBuilder builder;
    public N and() {
      return (N) HTTPChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
